Apply a butterworth filter, high pass or/and low pass, to sound samples. Based on the function butter
butter_filter(sound_samples, low = NA, high = NA, fs, tx, order = 10)Numeric vector with the sound samples to filter
Numeric. Minimum frequency in kHz for the butterworth filter
Numeric. Maximum frequency in kHz for the butterworth filter
Integer with the sampling frequency of the recording
Integer indicating the expanded time factor of the recording
Integer indicating the filter order to apply to the recording
A vector with the filtered sound samples
Butterworth filter